==> annofabcli-1.34.4-py3-none-any.whl: annofabcli/experimental/merge_visualization_dir.py <==
import argparse
import logging
from pathlib import Path
from typing import List, Optional

import pandas
from annofabcli.statistics.csv import Csv
import annofabcli
from annofabcli.common.cli import get_list_from_args
from annofabcli.common.utils import print_csv
from annofabcli.experimental.merge_peformance_per_date import merge_peformance_per_date
from annofabcli.experimental.merge_peformance_per_user import merge_peformance_per_user
from annofabcli.experimental.write_linegraph_per_user import write_linegraph_per_user
from annofabcli.experimental.write_performance_scatter_per_user import write_performance_scatter_per_user
from annofabcli.experimental.write_task_histogram import write_task_histogram
from annofabcli.experimental.write_whole_linegraph import write_whole_linegraph

logger = logging.getLogger(__name__)


FILENAME_PEFORMANCE_PER_USER = "メンバごとの生産性と品質.csv"
FILENAME_PEFORMANCE_PER_DATE = "日毎の生産量と生産性.csv"
FILENAME_TASK_LIST = "タスクlist.csv"


def merge_visualization(
    project_dir_list: List[Path],
    output_dir: Path,
    user_id_list: Optional[List[str]] = None,
    minimal_output: bool = False,
):
    def execute_merge_peformance_per_user():
        performance_per_user_csv_list = [dir / FILENAME_PEFORMANCE_PER_USER for dir in project_dir_list]
        merge_peformance_per_user(
            csv_path_list=performance_per_user_csv_list, output_path=output_dir / FILENAME_PEFORMANCE_PER_USER
        )

    def execute_merge_peformance_per_date():
        performance_per_date_csv_list = [dir / FILENAME_PEFORMANCE_PER_DATE for dir in project_dir_list]
        merge_peformance_per_date(
            csv_path_list=performance_per_date_csv_list, output_path=output_dir / FILENAME_PEFORMANCE_PER_DATE
        )

    def merge_task_list() -> pandas.DataFrame:
        list_df = [pandas.read_csv(str(dir / FILENAME_TASK_LIST)) for dir in project_dir_list]
        df = pandas.concat(list_df, axis=0)
        return df

    def write_csv_for_summary(df_task:pandas.DataFrame) -> None:
        """
        タスク関係のCSVを出力する。
        """
        csv_obj = Csv(str(output_dir))
        csv_obj.write_task_count_summary(df_task)
        csv_obj.write_worktime_summary(df_task)
        csv_obj.write_count_summary(df_task)


    # CSV生成
    execute_merge_peformance_per_user()
    execute_merge_peformance_per_date()
    df_task = merge_task_list()
    print_csv(df_task, output=str(output_dir / FILENAME_TASK_LIST))
    write_csv_for_summary(df_task)

    # HTML生成
    write_performance_scatter_per_user(csv=output_dir / FILENAME_PEFORMANCE_PER_USER, output_dir=output_dir / "scatter")
    write_whole_linegraph(csv=output_dir / FILENAME_PEFORMANCE_PER_DATE, output_dir=output_dir / "line-graph")
    write_linegraph_per_user(
        csv=output_dir / FILENAME_TASK_LIST, output_dir=output_dir / "line-graph", minimal_output=minimal_output, user_id_list=user_id_list
    )
    write_task_histogram(
        csv=output_dir / FILENAME_TASK_LIST, output_dir=output_dir / "histogram", minimal_output=minimal_output
    )


def main(args):
    user_id_list = get_list_from_args(args.user_id) if args.user_id is not None else None
    merge_visualization(
        project_dir_list=args.dir,
        user_id_list=user_id_list,
        minimal_output=args.minimal,
        output_dir=args.output_dir,
    )


def parse_args(parser: argparse.ArgumentParser):
    parser.add_argument("--dir", type=Path, nargs="+", required=True, help="マージ対象ディレクトリ")
    parser.add_argument("-o", "--output_dir", type=Path, required=True, help="出力先ディレクトリ。配下にプロジェクト名のディレクトリが出力される。")

    parser.add_argument(
        "-u",
        "--user_id",
        nargs="+",
        help=(
            "ユーザごとの折れ線グラフで絞り込むユーザのuser_idを指定してください。"
            "指定しない場合は、上位20人のユーザ情報がプロットされます。"
            "file://`を先頭に付けると、一覧が記載されたファイルを指定できます。"
        ),
    )

    parser.add_argument(
        "--minimal",
        action="store_true",
        help="必要最小限のファイルを出力します。",
    )

    parser.set_defaults(subcommand_func=main)


def add_parser(subparsers: argparse._SubParsersAction):
    subcommand_name = "merge_visualization_dir"
    subcommand_help = "`annofabcli statistics visualize`コマンドの出力結果をマージする。"
    description = "`annofabcli statistics visualize`コマンドの出力結果をマージする。"
    parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description)
    parse_args(parser)

==> annofabcli-1.34.13-py3-none-any.whl: annofabcli/experimental/merge_visualization_dir.py <==
import argparse
import logging
from pathlib import Path
from typing import List, Optional

import pandas

import annofabcli
from annofabcli.common.cli import get_list_from_args
from annofabcli.common.utils import print_csv, print_json
from annofabcli.experimental.merge_peformance_per_date import merge_peformance_per_date
from annofabcli.experimental.merge_peformance_per_user import merge_peformance_per_user
from annofabcli.experimental.write_linegraph_per_user import write_linegraph_per_user
from annofabcli.experimental.write_performance_scatter_per_user import write_performance_scatter_per_user
from annofabcli.experimental.write_task_histogram import write_task_histogram
from annofabcli.experimental.write_whole_linegraph import write_whole_linegraph
from annofabcli.statistics.csv import Csv

logger = logging.getLogger(__name__)


FILENAME_PEFORMANCE_PER_USER = "メンバごとの生産性と品質.csv"
FILENAME_PEFORMANCE_PER_DATE = "日毎の生産量と生産性.csv"
FILENAME_TASK_LIST = "タスクlist.csv"


def merge_visualization(
    project_dir_list: List[Path],
    output_dir: Path,
    user_id_list: Optional[List[str]] = None,
    minimal_output: bool = False,
):
    def execute_merge_peformance_per_user():
        performance_per_user_csv_list = [dir / FILENAME_PEFORMANCE_PER_USER for dir in project_dir_list]
        merge_peformance_per_user(
            csv_path_list=performance_per_user_csv_list, output_path=output_dir / FILENAME_PEFORMANCE_PER_USER
        )

    def execute_merge_peformance_per_date():
        performance_per_date_csv_list = [dir / FILENAME_PEFORMANCE_PER_DATE for dir in project_dir_list]
        merge_peformance_per_date(
            csv_path_list=performance_per_date_csv_list, output_path=output_dir / FILENAME_PEFORMANCE_PER_DATE
        )

    def merge_task_list() -> pandas.DataFrame:
        list_df = [pandas.read_csv(str(dir / FILENAME_TASK_LIST)) for dir in project_dir_list]
        df = pandas.concat(list_df, axis=0)
        return df

    def write_csv_for_summary(df_task: pandas.DataFrame) -> None:
        """
        タスク関係のCSVを出力する。
        """
        csv_obj = Csv(str(output_dir))
        csv_obj.write_task_count_summary(df_task)
        csv_obj.write_worktime_summary(df_task)
        csv_obj.write_count_summary(df_task)

    def write_info_json() -> None:
        info = {"target_dir_list": [str(e) for e in project_dir_list]}
        print_json(info, is_pretty=True, output=str(output_dir / "info.json"))

    # CSV生成
    execute_merge_peformance_per_user()
    execute_merge_peformance_per_date()
    df_task = merge_task_list()
    print_csv(df_task, output=str(output_dir / FILENAME_TASK_LIST))
    write_csv_for_summary(df_task)

    # HTML生成
    write_performance_scatter_per_user(csv=output_dir / FILENAME_PEFORMANCE_PER_USER, output_dir=output_dir / "scatter")
    write_whole_linegraph(csv=output_dir / FILENAME_PEFORMANCE_PER_DATE, output_dir=output_dir / "line-graph")
    write_linegraph_per_user(
        csv=output_dir / FILENAME_TASK_LIST,
        output_dir=output_dir / "line-graph",
        minimal_output=minimal_output,
        user_id_list=user_id_list,
    )
    write_task_histogram(
        csv=output_dir / FILENAME_TASK_LIST, output_dir=output_dir / "histogram", minimal_output=minimal_output
    )

    # info.jsonを出力
    write_info_json()


def main(args):
    user_id_list = get_list_from_args(args.user_id) if args.user_id is not None else None
    merge_visualization(
        project_dir_list=args.dir,
        user_id_list=user_id_list,
        minimal_output=args.minimal,
        output_dir=args.output_dir,
    )


def parse_args(parser: argparse.ArgumentParser):
    parser.add_argument("--dir", type=Path, nargs="+", required=True, help="マージ対象ディレクトリ")
    parser.add_argument("-o", "--output_dir", type=Path, required=True, help="出力先ディレクトリ。配下にプロジェクト名のディレクトリが出力される。")

    parser.add_argument(
        "-u",
        "--user_id",
        nargs="+",
        help=(
            "ユーザごとの折れ線グラフで絞り込むユーザのuser_idを指定してください。"
            "指定しない場合は、上位20人のユーザ情報がプロットされます。"
            "file://`を先頭に付けると、一覧が記載されたファイルを指定できます。"
        ),
    )

    parser.add_argument(
        "--minimal",
        action="store_true",
        help="必要最小限のファイルを出力します。",
    )

    parser.set_defaults(subcommand_func=main)


def add_parser(subparsers: argparse._SubParsersAction):
    subcommand_name = "merge_visualization_dir"
    subcommand_help = "`annofabcli statistics visualize`コマンドの出力結果をマージする。"
    description = "`annofabcli statistics visualize`コマンドの出力結果をマージする。"
    parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description)
    parse_args(parser)
